<!--![horn](.github/images/horn.svg "horn")-->

<p align="center">
  <img src=".github/images/horn.svg" alt='horn' title="horn"/>
</p>

<h1 align="center">Heimdallr</h1>

<!--# Heimdallr-->

A package for live plotting lab relevant information directly in your browser

<p align="center" width="100%">
  <a href="https://alexandra.dk">
    <img alt="Alexandra Instituttet"
    src="heimdallr/entry_points/assets/alexandra.png" height="40" align="left" title="Alexandra Instituttet"/>
  </a>
  <a href="http://python.org/">
    <img alt="python" src=".github/images/python.svg" height="40" align="left" title="python"/>
  </a>
</p>

<br/>

## Demo

![demo](.github/images/demo/demo.png "demo")

## Usage

- Setup MQTT broker connection information heimdallr mqtt_token
- On computation machines run the publisher service. heimdallr publish
- Run server service on the displaying machine. heimdallr serve
